@@ -1,5 +1,6 @@
 from sqlalchemy import create_engine
-from table_representation import Table
+from YamlBase.table_representation import Table
+
 
 class SQL:
 
