@@ -3,8 +3,8 @@
 import argparse
 import yaml
 import os
-# from ybase import YBase
-# from yaml_worker import YamlActionsWorker
+import ybase
+from yaml_worker import YamlActionsWorker
 
 import sys
 
